
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'portfolio/aboutme', {
        apiVersion: 2,
        title: 'About me',
        icon: 'block-default',
        category: 'pagesections',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            image: {
                type: 'object',
                default: {id: 0, url: 'https://images.unsplash.com/photo-1613909207039-6b173b755cc1?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDV8fGRlc2lnbmVyfGVufDB8fHx8MTYzMjg2OTMwMA&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=800&h=1000&fit=crop', size: ''},
            },
            top_heading: {
                type: 'text',
                default: `A little`,
            },
            title: {
                type: 'text',
                default: `About Me`,
            },
            description: {
                type: 'text',
                default: `Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Curabitur ac sagittis neque, vel egestas est.`,
            },
            button_link: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            button_label: {
                type: 'text',
                default: `Full Story`,
            }
        },
        example: { attributes: { image: {id: 0, url: 'https://images.unsplash.com/photo-1613909207039-6b173b755cc1?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDV8fGRlc2lnbmVyfGVufDB8fHx8MTYzMjg2OTMwMA&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=800&h=1000&fit=crop', size: ''}, top_heading: `A little`, title: `About Me`, description: `Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Curabitur ac sagittis neque, vel egestas est.`, button_link: {post_id: 0, url: '#', title: '', 'post_type': null}, button_label: `Full Story` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'pb-5 pt-5' });
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'g-3 mb-4 row' }, {
                allowedBlocks: [ 'portfolio/counter' ],
                template: [
    [ 'portfolio/counter', {} ],
    [ 'portfolio/counter', {} ],
    [ 'portfolio/counter', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'container pb-5 pt-5' }, el('div', { className: 'align-items-center gy-4 row' }, [el('div', { className: 'col-lg-4' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid rounded-1 shadow-sm w-100', alt: '...', width: '600', height: '650' })]), el('div', { className: 'col-lg-8' }, [el(RichText, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_heading, 'top_heading' ), onChange: function(val) { setAttributes( {top_heading: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h3', className: 'fw-bold h1 mb-3 text-capitalize text-primary', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'mb-4', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) } }), el('div', { ...innerBlocksProps }), el(RichText, { tagName: 'a', href: '#', className: 'btn btn-primary pe-4 ps-4', value: propOrDefault( props.attributes.button_label, 'button_label' ), onChange: function(val) { setAttributes( {button_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })])]))),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'full', false ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.top_heading,
                                        help: __( '' ),
                                        label: __( 'Top heading' ),
                                        onChange: function(val) { setAttributes({top_heading: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Description' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.description,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({description: val}) },
                                        })
                                    ]),
                                    pgUrlControl('button_link', setAttributes, props, 'Button link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.button_label,
                                        help: __( '' ),
                                        label: __( 'Button label' ),
                                        onChange: function(val) { setAttributes({button_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'pb-5 pt-5' });
            return el('section', { ...blockProps }, el('div', { className: 'container pb-5 pt-5' }, el('div', { className: 'align-items-center gy-4 row' }, [el('div', { className: 'col-lg-4' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid rounded-1 shadow-sm w-100', alt: '...', width: '600', height: '650' })]), el('div', { className: 'col-lg-8' }, [el(RichText.Content, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_heading, 'top_heading' ) }), el(RichText.Content, { tagName: 'h3', className: 'fw-bold h1 mb-3 text-capitalize text-primary', value: propOrDefault( props.attributes.title, 'title' ) }), el(RichText.Content, { tagName: 'p', className: 'mb-4', value: propOrDefault( props.attributes.description, 'description' ) }), el('div', { className: 'g-3 mb-4 row' }, el(InnerBlocks.Content, { allowedBlocks: [ 'portfolio/counter' ] })), el(RichText.Content, { tagName: 'a', href: propOrDefault( props.attributes.button_link.url, 'button_link', 'url' ), className: 'btn btn-primary pe-4 ps-4', value: propOrDefault( props.attributes.button_label, 'button_label' ) })])])));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
