
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'portfolio/full-screen', {
        apiVersion: 2,
        title: 'Full Screen',
        icon: 'block-default',
        category: 'pagesections',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            background_image: {
                type: 'object',
                default: '',
            },
            top_heading: {
                type: 'text',
                default: `Few words from my clients`,
            },
            title: {
                type: 'text',
                default: `Testimonials`,
            }
        },
        example: { attributes: { background_image: '', top_heading: `Few words from my clients`, title: `Testimonials` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'background-cover bg-light d-flex flex-column justify-content-center min-vh-100 pb-5 pt-5 text-secondary', style: { backgroundImage: 'url(\'' + propOrDefault( props.attributes.background_image.url, 'background_image', 'url' ) + '\')' } });
            const setAttributes = props.setAttributes; 
            
            props.background_image = useSelect(function( select ) {
                return {
                    background_image: props.attributes.background_image.id ? select('core').getMedia(props.attributes.background_image.id) : undefined
                };
            }, [props.attributes.background_image] ).background_image;
            
            const innerBlocksProps = useInnerBlocksProps({}, {
                template: [
    [ 'portfolio/contact-form', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'container' }, el('div', { className: 'justify-content-center row' }, el('div', { className: 'col-10 col-lg-7 pb-3 pt-3' }, el('div', { className: 'bg-white h-100 rounded shadow' }, el('div', { className: 'p-4' }, [el(RichText, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_heading, 'top_heading' ), onChange: function(val) { setAttributes( {top_heading: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h3', className: 'fw-bold h1 text-primary', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('div', { ...innerBlocksProps })])))))),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('background_image', setAttributes, props, 'full', false ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.top_heading,
                                        help: __( '' ),
                                        label: __( 'Top heading' ),
                                        onChange: function(val) { setAttributes({top_heading: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'background-cover bg-light d-flex flex-column justify-content-center min-vh-100 pb-5 pt-5 text-secondary', style: { backgroundImage: 'url(\'' + propOrDefault( props.attributes.background_image.url, 'background_image', 'url' ) + '\')' } });
            return el('section', { ...blockProps }, el('div', { className: 'container' }, el('div', { className: 'justify-content-center row' }, el('div', { className: 'col-10 col-lg-7 pb-3 pt-3' }, el('div', { className: 'bg-white h-100 rounded shadow' }, el('div', { className: 'p-4' }, [el(RichText.Content, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_heading, 'top_heading' ) }), el(RichText.Content, { tagName: 'h3', className: 'fw-bold h1 text-primary', value: propOrDefault( props.attributes.title, 'title' ) }), el('div', {}, el(InnerBlocks.Content, {}))]))))));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
