
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'portfolio/projects', {
        apiVersion: 2,
        title: 'Projects',
        icon: 'block-default',
        category: 'pagesections',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            top_title: {
                type: 'text',
                default: `Some of my recent projects`,
            },
            title: {
                type: 'text',
                default: `Works`,
            },
            button_link: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            button_label: {
                type: 'text',
                default: `View All`,
            }
        },
        example: { attributes: { top_title: `Some of my recent projects`, title: `Works`, button_link: {post_id: 0, url: '#', title: '', 'post_type': null}, button_label: `View All` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'pb-5 pt-5' });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'gy-5 justify-content-center row row-cols-md-2' }, {
                allowedBlocks: [ 'portfolio/project' ],
                template: [
    [ 'portfolio/project', {} ],
    [ 'portfolio/project', {} ],
    [ 'portfolio/project', {} ],
    [ 'portfolio/project', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'container pb-5 pt-5' }, [el(RichText, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_title, 'top_title' ), onChange: function(val) { setAttributes( {top_title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h3', className: 'fw-bold h1 mb-5 text-primary', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('div', { ...innerBlocksProps }), el('div', { className: 'mt-5' }, el(RichText, { tagName: 'a', href: '#', className: 'btn btn-primary pb-2 pe-4 ps-4 pt-2', value: propOrDefault( props.attributes.button_label, 'button_label' ), onChange: function(val) { setAttributes( {button_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }))])),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.top_title,
                                        help: __( '' ),
                                        label: __( 'Top tile' ),
                                        onChange: function(val) { setAttributes({top_title: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('button_link', setAttributes, props, 'Button link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.button_label,
                                        help: __( '' ),
                                        label: __( 'Button label' ),
                                        onChange: function(val) { setAttributes({button_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'pb-5 pt-5' });
            return el('section', { ...blockProps }, el('div', { className: 'container pb-5 pt-5' }, [el(RichText.Content, { tagName: 'h2', className: 'h6 text-capitalize', value: propOrDefault( props.attributes.top_title, 'top_title' ) }), el(RichText.Content, { tagName: 'h3', className: 'fw-bold h1 mb-5 text-primary', value: propOrDefault( props.attributes.title, 'title' ) }), el('div', { className: 'gy-5 justify-content-center row row-cols-md-2' }, el(InnerBlocks.Content, { allowedBlocks: [ 'portfolio/project' ] })), el('div', { className: 'mt-5' }, el(RichText.Content, { tagName: 'a', href: propOrDefault( props.attributes.button_link.url, 'button_link', 'url' ), className: 'btn btn-primary pb-2 pe-4 ps-4 pt-2', value: propOrDefault( props.attributes.button_label, 'button_label' ) }))]));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
