<?php
if ( ! function_exists( 'portfolio_setup' ) ) :

function portfolio_setup() {

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    /* Pinegrow generated Load Text Domain Begin */
    load_theme_textdomain( 'portfolio', get_template_directory() . '/languages' );
    /* Pinegrow generated Load Text Domain End */

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     */
    add_theme_support( 'title-tag' );
    
    /*
     * Enable support for Post Thumbnails on posts and pages.
     */
    add_theme_support( 'post-thumbnails' );
    //Support custom logo
    add_theme_support( 'custom-logo' );

    // Add menus.
    register_nav_menus( array(
        'primary' => __( 'Primary Menu', 'portfolio' ),
        'social'  => __( 'Social Links Menu', 'portfolio' ),
    ) );

/*
     * Register custom menu locations
     */
    /* Pinegrow generated Register Menus Begin */

    /* Pinegrow generated Register Menus End */
    
/*
    * Set image sizes
     */
    /* Pinegrow generated Image Sizes Begin */

    add_image_size( 'large_square', 800, 800, true );
    /* Pinegrow generated Image Sizes End */
    
    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

    /*
     * Enable support for Post Formats.
     */
    add_theme_support( 'post-formats', array(
        'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
    ) );

    /*
     * Enable support for Page excerpts.
     */
     add_post_type_support( 'page', 'excerpt' );
}
endif; // portfolio_setup

add_action( 'after_setup_theme', 'portfolio_setup' );


if ( ! function_exists( 'portfolio_init' ) ) :

function portfolio_init() {

    
    // Use categories and tags with attachments
    register_taxonomy_for_object_type( 'category', 'attachment' );
    register_taxonomy_for_object_type( 'post_tag', 'attachment' );

    /*
     * Register custom post types. You can also move this code to a plugin.
     */
    /* Pinegrow generated Custom Post Types Begin */

    /* Pinegrow generated Custom Post Types End */
    
    /*
     * Register custom taxonomies. You can also move this code to a plugin.
     */
    /* Pinegrow generated Taxonomies Begin */

    /* Pinegrow generated Taxonomies End */

}
endif; // portfolio_setup

add_action( 'init', 'portfolio_init' );


if ( ! function_exists( 'portfolio_custom_image_sizes_names' ) ) :

function portfolio_custom_image_sizes_names( $sizes ) {

    /*
     * Add names of custom image sizes.
     */
    /* Pinegrow generated Image Sizes Names Begin */

    return array_merge( $sizes, array(
        'large_square' => __( 'Large square' )
    ) );

    /* Pinegrow generated Image Sizes Names End */
    return $sizes;
}
add_action( 'image_size_names_choose', 'portfolio_custom_image_sizes_names' );
endif;// portfolio_custom_image_sizes_names



if ( ! function_exists( 'portfolio_widgets_init' ) ) :

function portfolio_widgets_init() {

    /*
     * Register widget areas.
     */
    /* Pinegrow generated Register Sidebars Begin */

    /* Pinegrow generated Register Sidebars End */
}
add_action( 'widgets_init', 'portfolio_widgets_init' );
endif;// portfolio_widgets_init



if ( ! function_exists( 'portfolio_customize_register' ) ) :

function portfolio_customize_register( $wp_customize ) {
    // Do stuff with $wp_customize, the WP_Customize_Manager object.

    /* Pinegrow generated Customizer Controls Begin */

    /* Pinegrow generated Customizer Controls End */

}
add_action( 'customize_register', 'portfolio_customize_register' );
endif;// portfolio_customize_register


if ( ! function_exists( 'portfolio_enqueue_scripts' ) ) :
    function portfolio_enqueue_scripts() {

        /* Pinegrow generated Enqueue Scripts Begin */

    wp_deregister_script( 'portfolio-popper' );
    wp_enqueue_script( 'portfolio-popper', get_template_directory_uri() . '/assets/js/popper.min.js', false, null, true);

    wp_deregister_script( 'portfolio-bootstrap' );
    wp_enqueue_script( 'portfolio-bootstrap', get_template_directory_uri() . '/bootstrap/js/bootstrap.min.js', false, null, true);

    /* Pinegrow generated Enqueue Scripts End */

        /* Pinegrow generated Enqueue Styles Begin */

    wp_deregister_style( 'portfolio-bootstrap' );
    wp_enqueue_style( 'portfolio-bootstrap', get_template_directory_uri() . '/bootstrap_theme/bootstrap.css', false, null, 'all');

    wp_deregister_style( 'portfolio-blocks' );
    wp_enqueue_style( 'portfolio-blocks', get_template_directory_uri() . '/blocks.css', false, null, 'all');

    wp_deregister_style( 'portfolio-style' );
    wp_enqueue_style( 'portfolio-style', get_bloginfo('stylesheet_url'), false, null, 'all');

    /* Pinegrow generated Enqueue Styles End */

    }
    add_action( 'wp_enqueue_scripts', 'portfolio_enqueue_scripts' );
endif;

function pgwp_sanitize_placeholder($input) { return $input; }
/*
 * Resource files included by Pinegrow.
 */
/* Pinegrow generated Include Resources Begin */
require_once "inc/custom.php";
require_once "inc/wp_pg_helpers.php";
require_once "inc/wp_smart_navwalker.php";
require_once "inc/wp_pg_pagination.php";

    /* Pinegrow generated Include Resources End */

/* Setting up theme supports options */

function portfolio_setup_theme_supports() {
    // Don't edit anything between the following comments.
    /* Pinegrow generated Theme Supports Begin */
    
    //Tell WP to scope loaded editor styles to the block editor                    
    add_theme_support( 'editor-styles' );
    /* Pinegrow generated Theme Supports End */
}
add_action('after_setup_theme', 'portfolio_setup_theme_supports');

/* End of setting up theme supports options */


/* Loading editor styles for blocks */

function portfolio_add_blocks_editor_styles() {
    // Add blocks editor styles. Don't edit anything between the following comments.
    /* Pinegrow generated Load Blocks Editor Styles Begin */
    add_editor_style( 'bootstrap_theme/bootstrap.css' );
    add_editor_style( 'blocks.css' );

    /* Pinegrow generated Load Blocks Editor Styles End */
}
add_action('admin_init', 'portfolio_add_blocks_editor_styles');

/* End of loading editor styles for blocks */


/* Creating Editor Blocks with Pinegrow */

function portfolio_blocks_init() {
    // Register blocks. Don't edit anything between the following comments.
    /* Pinegrow generated Register Pinegrow Blocks Begin */
    require_once 'blocks/header/header_register.php';
    require_once 'blocks/hero/hero_register.php';
    require_once 'blocks/counter/counter_register.php';
    require_once 'blocks/aboutme/aboutme_register.php';
    require_once 'blocks/divider/divider_register.php';
    require_once 'blocks/project/project_register.php';
    require_once 'blocks/projects/projects_register.php';
    require_once 'blocks/recent-posts/recent-posts_register.php';
    require_once 'blocks/all-posts/all-posts_register.php';
    require_once 'blocks/quote/quote_register.php';
    require_once 'blocks/quotes/quotes_register.php';
    require_once 'blocks/footer/footer_register.php';
    require_once 'blocks/post-hero/post-hero_register.php';
    require_once 'blocks/post-content/post-content_register.php';

    /* Pinegrow generated Register Pinegrow Blocks End */
}
add_action('init', 'portfolio_blocks_init');

/* End of creating Editor Blocks with Pinegrow */


/* Register Blocks Categories */

function portfolio_register_blocks_categories( $categories ) {

    // Don't edit anything between the following comments.
    /* Pinegrow generated Register Blocks Category Begin */

$categories = array_merge( $categories, array( array(
        'slug' => 'pagesections',
        'title' => __( 'Page sections', 'portfolio' )
    ) ) );

    /* Pinegrow generated Register Blocks Category End */
    
    return $categories;
}
add_action( version_compare('5.8', get_bloginfo('version'), '>=' ) ? 'block_categories_all' : 'block_categories', 'portfolio_register_blocks_categories');

/* End of registering Blocks Categories */

?>